R/fct_duckdb.R
updateDuckMeta.Rd
Update the meta data table of a duckdb database
updateDuckMeta(con, assay = "RNA", data)
duckdb connection
meta data (data frame) to be updated, with the first column as 'cell'